@@ -6,12 +6,34 @@ from markdown.core import Markdown
 from markdown.extensions import Extension, fenced_code
 from markdown.preprocessors import Preprocessor
 
+from .settings import SyntaxHighlightingSettings
+
+
+def render_code(
+    code: str,
+    language: str | None,
+    settings: SyntaxHighlightingSettings,
+) -> str:
+    cmd = [
+        "code2html",
+        "--backend",
+        settings.backend,
+        "--class",
+        settings.css_class,
+        "--linenos-class",
+        settings.linenos_class,
+        "--input",
+        "-",
+        "--output",
+        "-",
+    ]
 
-def render_code(code: str, language: str | None) -> str:
-    cmd = ["code2html", "-i", "-", "-o", "-"]
     if language:
         cmd += ["-l", language]
 
+    if settings.linenos:
+        cmd.append("--linenos")
+
     rendered = (
         subprocess.check_output(
             cmd,
@@ -26,6 +48,10 @@ def render_code(code: str, language: str | None) -> str:
 class FencedCodeProcessor(Preprocessor):
     FENCED_BLOCK_RE = fenced_code.FencedBlockPreprocessor.FENCED_BLOCK_RE
 
+    def __init__(self, settings: SyntaxHighlightingSettings, md: Markdown):
+        super().__init__(md)
+        self.settings = settings
+
     def run(self, lines: list[str]) -> list[str]:
         text = "\n".join(lines)
         while True:
@@ -35,17 +61,22 @@ class FencedCodeProcessor(Preprocessor):
 
             lang = m.group("lang")
             code = m.group("code")
-            rendered = render_code(code, lang)
+            rendered = render_code(code, lang, self.settings)
             text = f"{text[: m.start()]}\n{rendered}\n{text[m.end() :]}"
 
         return text.split("\n")
 
 
 class FencedCodeExtension(Extension):
+    def __init__(self, settings: SyntaxHighlightingSettings):
+        super().__init__()
+
+        self.settings = settings
+
     def extendMarkdown(self, md: Markdown):
         md.registerExtension(self)
         md.preprocessors.register(
-            FencedCodeProcessor(md),
+            FencedCodeProcessor(self.settings, md),
             "syntax_highlighting_fenced_code_block",
             200,
         )
